Stan Math Library: stan/math/prim/mat/fun/value_of_rec.hpp File Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

Namespaces | Functions
value_of_rec.hpp File Reference
`#include <stan/math/prim/scal/fun/value_of_rec.hpp>`
`#include <stan/math/prim/mat/fun/Eigen.hpp>`

Go to the source code of this file.

## Namespaces
| stan
| stan::math
| Matrices and templated mathematical functions.

## Functions
template<typename T , int R, int C>
Eigen::Matrix< double, R, C > | stan::math::value_of_rec (const Eigen::Matrix< T, R, C > &M)
| Convert a matrix of type T to a matrix of doubles. More...
template<int R, int C>
Eigen::Matrix< double, R, C > | stan::math::value_of_rec (const Eigen::Matrix< double, R, C > &x)
| Return the specified argument. More...

[ Stan Home Page ] © 2011–2016, Stan Development Team.